import { FunctionResources, ResourceProvider } from '@aws-amplify/plugin-types';
import { Construct } from 'constructs';
export type ConversationHandlerFunctionProps = {
    entry?: string;
    models: Array<{
        modelId: string;
        region?: string;
    }>;
};
/**
 * Conversation Handler Function CDK construct.
 * This construct deploys resources that integrate conversation routes
 * defined in data schema with AI models available in AWS Bedrock. I.e.
 * 1. AWS Lambda function that handles conversation turn events.
 *    With Amplify provided implementation by default and option to specify
 *    custom handler.
 * 2. AWS CloudWatch log group policy with appropriate data protection policies.
 * 3. AWS IAM policy that grants access to selected AWS Bedrock models.
 */
export declare class ConversationHandlerFunction extends Construct implements ResourceProvider<FunctionResources> {
    private readonly props;
    resources: FunctionResources;
    /**
     * Creates Conversation Handler Function CDK construct.
     */
    constructor(scope: Construct, id: string, props: ConversationHandlerFunctionProps);
}
//# sourceMappingURL=conversation_handler_construct.d.ts.map